@@ -184,8 +184,6 @@ static void layer_surface_configure(void *data,
 	struct swaylock_surface *surface = data;
 	surface->width = width;
 	surface->height = height;
-	surface->indicator_width = 0;
-	surface->indicator_height = 0;
 	zwlr_layer_surface_v1_ack_configure(layer_surface, serial);
 	render_frame_background(surface);
 	render_frame(surface);
@@ -208,8 +206,6 @@ static void ext_session_lock_surface_v1_handle_configure(void *data,
 	struct swaylock_surface *surface = data;
 	surface->width = width;
 	surface->height = height;
-	surface->indicator_width = 0;
-	surface->indicator_height = 0;
 	ext_session_lock_surface_v1_ack_configure(lock_surface, serial);
 	render_frame_background(surface);
 	render_frame(surface);
@@ -1135,8 +1131,34 @@ static void term_in(int fd, short mask, void *data) {
 	state.run_display = false;
 }
 
-int main(int argc, char **argv) {
+// Check for --debug 'early' we also apply the correct loglevel
+// to the forked child, without having to first proces all of the
+// configuration (including from file) before forking and (in the
+// case of the shadow backend) dropping privileges
+void log_init(int argc, char **argv) {
+	static struct option long_options[] = {
+		{"debug", no_argument, NULL, 'd'},
+        {0, 0, 0, 0}
+    };
+    int c;
+	optind = 1;
+    while (1) {
+		int opt_idx = 0;
+		c = getopt_long(argc, argv, "-:d", long_options, &opt_idx);
+		if (c == -1) {
+			break;
+		}
+		switch (c) {
+		case 'd':
+			swaylock_log_init(LOG_DEBUG);
+			return;
+		}
+	}
 	swaylock_log_init(LOG_ERROR);
+}
+
+int main(int argc, char **argv) {
+	log_init(argc, argv);
 	initialize_pw_backend(argc, argv);
 	srand(time(NULL));
 
@@ -1265,6 +1287,9 @@ int main(int argc, char **argv) {
 		return 1;
 	}
 
+	state.test_surface = cairo_image_surface_create(CAIRO_FORMAT_RGB24, 1, 1);
+	state.test_cairo = cairo_create(state.test_surface);
+
 	struct swaylock_surface *surface;
 	wl_list_for_each(surface, &state.surfaces, link) {
 		create_surface(surface);
@@ -1299,5 +1324,7 @@ int main(int argc, char **argv) {
 	}
 
 	free(state.args.font);
+	cairo_destroy(state.test_cairo);
+	cairo_surface_destroy(state.test_surface);
 	return 0;
 }
